#########################################################################
#
# Author : Bertrand Iooss
#
# Fichier : Flood.R
# Date : 2013
#
# Description :
# This function is a simplified model of a river flood and of a dyke maintenance cost
#              (based on a  1D simplification of St Venant equations)
#
# Outputs : S = overflowing height (in meters) between water height and dyke height
#           Cp = annual cost of dyke maintenance (in Meuros)
#
# Inputs :
# X : A vector of 8 components or a matrix of a 8 columns
# X[1] = Q flowrate (in m3/s), truncated gumbel max (loc=1013,scale=558,min=500,max=3000)
# X[2] = Ks Strickler coefficient, truncated Gaussian (30,8,min=15)
# X[3] = Zv (in m) downstream river bed height, triangular (50,+-1)
# X[4] = Zm (in m) upstream river bed height, triangular (55,+-1)
# X[5] = Hd (in m) dyke height, uniform (7,9)
# X[6] = Cb (in m) bank height, triangular (55.5,+-0.5)
# X[7] = L (in m) river length (between upstream and downstream), triangular (5000,+-10)
# X[8] = B (in m), triangular (300,+-5)
#
# ans : parameter allowing to define the returned output 
#       0 -> 2 outputs ; 1 -> S ; 2 -> Cp
#
#########################################################################

Flood <- function(X,ans=0){

  mat = matrix(X,ncol=8);
  if (ans==0){ reponse=matrix(NA,nrow(mat),2);}
  else{ reponse=rep(NA,nrow(mat));}

  for (i in 1:nrow(mat)) {

	H = (mat[i,1] / (mat[i,2]*mat[i,8]*sqrt((mat[i,4] - mat[i,3])/mat[i,7])))^(0.6) ;
	S = mat[i,3] + H - mat[i,5] - mat[i,6] ;

        if (S > 0){ Cp = 1 ;}
        else{ Cp = 0.2 + 0.8 * (1 - exp(-1000 / S^4));}
        if (mat[i,5]>8){ Cp = Cp + mat[i,5]/20 ;}
        else{ Cp = Cp + 8/20 ;}

  if (ans==0){
	reponse[i,1] = S ;
	reponse[i,2] = Cp ;
  }
  if (ans==1){ reponse[i] = S ;}
  if (ans==2){ reponse[i] = Cp ;}

	}#end for

  return(RES=reponse)

}#end function
